@@ -52,7 +52,7 @@ def test_example(path):
         msg = '%s\nSTDOUT:\n%s' % (msg, outs)
     if errs:
         msg = '%s\nSTDERR:\n%s' % (msg, errs)
-    assert proc.returncode == 0, msg
+    assert proc.returncode <= 0, msg
 
 
 
