@@ -358,6 +358,21 @@ else:
         return sig, codegen
 
 
+                       
+@nb.generated_jit(nopython=True)
+def convert_scalar(arr):
+    """ helper function that turns 0d-arrays into scalars
+    
+    This helps to avoid the bug discussed in
+    https://github.com/numba/numba/issues/6000
+    """
+    if isinstance(arr, nb.types.Array) and arr.ndim == 0:
+        return lambda arr: arr[()]
+    else:
+        return lambda arr: arr
+
+   
+
 
 if NUMBA_VERSION < [0, 45]:
     warnings.warn('Your numba version is outdated. Please install at least '
