@@ -5,12 +5,11 @@ Functions and classes for visualizing simulations.
 .. autosummary::
    :nosignatures:
 
-   contexts
    movies
    plotting
    
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
 '''
 
-from .plotting import plot_magnitudes, plot_kymograph
+from .plotting import plot_magnitudes, plot_kymograph, plot_kymographs
 from .movies import movie_scalar, movie_multiple
